@@ -10,14 +10,29 @@ GENERATED_REPO_DIR = GENERATED_FILES_DIR / "project"
 TEMPLATES_DIR = INPUT_FILES_DIR / "templates"
 
 COOKIECUTTERS_DIR = TEMPLATES_DIR / "cookiecutters"
-COOKIECUTTER_ONE_DIR = COOKIECUTTERS_DIR / "one"
-COOKIECUTTER_TWO_DIR = COOKIECUTTERS_DIR / "two"
-COOKIECUTTER_ONE_VERSION = "d512c7e14e83cb4bc8d4e5ae06bb357e"
-COOKIECUTTER_REMOTE_URL = "https://github.com/nickderobertis/cookiecutter-simple-example"
+COOKIECUTTER_ONE_NAME = "one"
+COOKIECUTTER_TWO_NAME = "two"
+COOKIECUTTER_ONE_DIR = COOKIECUTTERS_DIR / COOKIECUTTER_ONE_NAME
+COOKIECUTTER_TWO_DIR = COOKIECUTTERS_DIR / COOKIECUTTER_TWO_NAME
+COOKIECUTTER_ONE_VERSION = "1c154af24ff30bc4cab8cf9d543304d9"
+COOKIECUTTER_ONE_MODIFIED_VERSION = "2dc435b3d7e256fbdcc78e62faaabff4"
+COOKIECUTTER_REMOTE_URL = (
+    "https://github.com/nickderobertis/cookiecutter-simple-example"
+)
 COOKIECUTTER_REMOTE_NAME = "cookiecutter-simple-example"
 COOKIECUTTER_REMOTE_VERSION_1 = "c390901c4fd599473bdb95fa4dd3d2a6eb2b34f0"
 COOKIECUTTER_REMOTE_VERSION_2 = "ee8da996b5d74dfcbba5727d7c950c88173dc9ca"
 
+COPIERS_DIR = TEMPLATES_DIR / "copiers"
+COPIER_ONE_NAME = "one"
+COPIER_ONE_DIR = COPIERS_DIR / COPIER_ONE_NAME
+COPIER_ONE_VERSION = "a01b15276b7ba87dee75b0668b9587bb"
+COPIER_ONE_MODIFIED_VERSION = "does not matter yet for tests"
+COPIER_REMOTE_URL = "https://github.com/nickderobertis/copier-simple-example"
+COPIER_REMOTE_NAME = "copier-simple-example"
+COPIER_REMOTE_VERSION_1 = "c7e1ba1bfb141e9c577e7c21ee4a5d3ae5dde04d"
+COPIER_REMOTE_VERSION_2 = "f3fa2c9526c12b3011e0a26108ce141373539bca"
+
 CONFIGS_DIR = INPUT_FILES_DIR / "configs"
 CONFIG_1_PATH = CONFIGS_DIR / "flexlate.json"
 CONFIG_SUBDIR_1 = CONFIG_1_PATH / "subdir1"
@@ -33,6 +48,5 @@ PROJECT_CONFIGS_PROJECT_2_SUBDIR = PROJECT_CONFIGS_PROJECT_2_PATH / "subdir"
 PROJECT_CONFIGS_1_CONFIG_PATH = PROJECT_CONFIGS_PROJECT_1_PATH / "flexlate-project.json"
 
 
-
 if not GENERATED_FILES_DIR.exists():
-    GENERATED_FILES_DIR.mkdir()
\ No newline at end of file
+    GENERATED_FILES_DIR.mkdir()
