@@ -1,4 +1,5 @@
 from flexlate.render.renderable import Renderable
+from flexlate.template.copier import CopierTemplate
 from tests.config import GENERATED_FILES_DIR
 from tests.fixtures.template import *
 
@@ -10,6 +11,13 @@ def cookiecutter_one_renderable(
     return Renderable(template=cookiecutter_one_template, out_root=GENERATED_FILES_DIR)
 
 
+@pytest.fixture
+def copier_one_renderable(
+    copier_one_template: CopierTemplate,
+) -> Renderable:
+    return Renderable(template=copier_one_template, out_root=GENERATED_FILES_DIR)
+
+
 @pytest.fixture
 def cookiecutter_two_renderable(
     cookiecutter_two_template: CookiecutterTemplate,
